# Space Systems Software Library - Python Edition (libs3py)
Note: this is a work in progress.  Very (very!) unstable.



## Build from source

1. Install build dependencies.
~~~~
python -m pip install --upgrade build
~~~~

2. Build package.
~~~~
python -m build
~~~~

3. Install package locally.
~~~
pip install dist/s3py-.....whl
~~~